# All Components

If you haven't already, first check out [Component](ical_library.base_classes.Component) over at [base classes](The base classes).
These are part of the components you can encounter in a iCalendar data file. The others are mentioned in [Recurring components](Recurring components) and [Timezone components](/iCal-library/code/timezone_components/).

## Simple components
We start out with the components that are relatively straight forward. There is no recurring option here.

::: ical_library.ical_components.VFreeBusy

::: ical_library.ical_components.VAlarm
